Errata — bodhi 4.0.0 documentation

# Errata

## Python objects

Message schema for Errata.

Each message is defined as a Python class. For details, see fedora-messaging documentation on messages.

class `bodhi.messages.schemas.errata.` `ErrataPublishV1`(body=None, headers=None, topic=None, properties=None, severity=None)

  Bases: `bodhi.messages.schemas.base.BodhiMessage`

  Sent when an errata is published.

  `__str__`() → str

    Return a human-readable representation of this message.

    This should provide a detailed representation of the message, much like the body of an email.

  `agent`

    Return the agent’s username for this message.

    Returns: | The agent’s username.

  `packages`

    List of package names affected by the action that generated this message.

    Returns: | A list of affected package names.

  `summary`

    Return a short, human-readable representation of this message.

    This should provide a short summary of the message, much like the subject line of an email.

  `topic` = 'bodhi.errata.publish'
  `update`

    Return the Update from this errata.

  `url`

    Return a URL to the action that caused this message to be emitted.

    Returns: | A relevant URL.

## JSON schemas

### bodhi.errata.publish

    {
        "id": "https://bodhi.fedoraproject.org/message-schemas/v1/bodhi.errata.publish#",
        "$schema": "http://json-schema.org/draft-04/schema#",
        "description": "Schema for message sent when an update is pushed to stable",
        "type": "object",
        "properties": {
            "body": {
                "type": "string",
                "description": "The body of an human readable message about the update"
            },
            "subject": {
                "type": "string",
                "description": "A short summary of the update"
            },
            "update": {
                "type": "object",
                "description": "An update",
                "properties": {
                    "alias": {
                        "type": "string",
                        "description": "The alias of the update"
                    },
                    "builds": {
                        "type": "array",
                        "description": "A list of builds included in this update",
                        "items": {
                            "$ref": "#/definitions/build"
                        }
                    },
                    "request": {
                        "type": [
                            "null",
                            "string"
                        ],
                        "description": "The request of the update, if any",
                        "enum": [
                            null,
                            "testing",
                            "obsolete",
                            "unpush",
                            "revoke",
                            "stable"
                        ]
                    },
                    "status": {
                        "type": "string",
                        "description": "The current status of the update",
                        "enum": [
                            null,
                            "pending",
                            "testing",
                            "stable",
                            "unpushed",
                            "obsolete",
                            "side_tag_active",
                            "side_tag_expired"
                        ]
                    },
                    "user": {
                        "type": "object",
                        "description": "The user that submitted the override",
                        "properties": {
                            "name": {
                                "type": "string",
                                "description": "The user's account name"
                            }
                        },
                        "required": [
                            "name"
                        ]
                    }
                },
                "required": [
                    "alias",
                    "builds",
                    "request",
                    "status",
                    "user"
                ]
            }
        },
        "required": [
            "body",
            "subject",
            "update"
        ],
        "definitions": {
            "build": {
                "type": "object",
                "description": "A build",
                "properties": {
                    "nvr": {
                        "type": "string",
                        "description": "The nvr the identifies the build in koji"
                    }
                },
                "required": [
                    "nvr"
                ]
            }
        }
    }